# lazer

A Python package that enables easier setup for function-enabled GPT models like gpt-3.5-turbo-0613


### Installation

`$ pip install lazer`


### Usage

Go check `lazer/user/app.py` for a dummy app
